local widget = require( "widget" )

local function scrollListener( event )
 --[[
    local phase = event.phase
    if ( phase == "began" ) then print( "Scroll view was touched" )
    elseif ( phase == "moved" ) then print( "Scroll view was moved" )
    elseif ( phase == "ended" ) then print( "Scroll view was released" )
    end
 
    -- In the event a scroll limit is reached...
    if ( event.limitReached ) then
        if ( event.direction == "up" ) then print( "Reached bottom limit" )
        elseif ( event.direction == "down" ) then print( "Reached top limit" )
        elseif ( event.direction == "left" ) then print( "Reached right limit" )
        elseif ( event.direction == "right" ) then print( "Reached left limit" )
        end
    end
 ]]--
    return true
end

local lib = {}

local _H = display.contentHeight
local _W = display.contentWidth
local MenuLableWidth = 200
local MenuLableHeight = 50


local function CreateNewLable(Text, x, y, w, h)
	local newGroup = display.newGroup()
	newGroup.anchorChildren = true
	newGroup.x = x
	newGroup.y = y
	newGroup.rect = display.newRect(newGroup, 0,0, w, h)
	local MenuLable = newGroup.rect
	newGroup.text = display.newText(newGroup,
		Text,
		MenuLable.x, MenuLable.y,
		native.systemFont, 20)
	local MenuLableText = newGroup.text
	
	return newGroup
end


function lib:Create(newMenuTable)
	local newMenu = newMenuTable or {}
	local list = {}
	
	self.scrollView = widget.newScrollView(
		{
			top = _H*0.2,
			left = _W*0.125,
			width = MenuLableWidth,
			height = MenuLableHeight*9,
			scrollWidth = MenuLableWidth,
			scrollHeight = #newMenu,
			horizontalScrollDisabled=true,
			isBounceEnabled=false,
			backgroundColor = { 0,0,0, 0.8 },
			listener = scrollListener
		}
	)
	local scrollView = self.scrollView
	
	for r=1, #newMenu do
		local value = newMenu[r]
		local key = value.id
		local newLable = CreateNewLable(value.name, 0, (r-1)*MenuLableHeight, MenuLableWidth, MenuLableHeight)
		newLable.anchorY = 0
		newLable.anchorX = 0
		newLable.rect.fill.effect= "generator.linearGradient"
		newLable.rect.fill.effect.color1 = { 0.8, 0, 0.2, 0.8 }
		newLable.rect.fill.effect.position1  = { 0.5, 0.5 }
		newLable.rect.fill.effect.color2 = { 0, 0, 0, 1 }
		newLable.rect.fill.effect.position2  = { 1, 1 }
		newLable.id = r
		newLable.origY = newLable.y
		
		
		function newLable:OpenSub(id, itemID)
			if list[id].itemsGroup.isVisible then return end
			for i=1, #list do
				list[i].y = list[i].origY
				list[i].itemsGroup.isVisible = false
				for k=1, #list[i].items do
					local group = list[i].items[k].group
					local name = list[i].items[k].name
					local item = list[i].items[k].item
					group.isVisible = false
					item.rect:setFillColor(23/255,45/255,58/255)
				end
			end
			if #self.items ~= 0 then
				list[id].itemsGroup.isVisible = true
				list[id].itemsGroup.alpha=1
				transition.from(list[id].itemsGroup, {time=350, alpha=0})
				if itemID then
					list[id].items[itemID].group.isVisible = true
					list[id].items[itemID].item.rect:setFillColor(9/255,112/255,230/255)
				else
					list[id].items[1].group.isVisible = true
					list[id].items[1].item.rect:setFillColor(9/255,112/255,230/255)
				end
				for i=id+1, #list do
					transition.to(list[i], {time=100, y=list[i].y + ((#self.items)*MenuLableHeight)})
				end
			else
				list[id].itemsGroup.isVisible = true
				list[id].items.group.isVisible = true
			end
			scrollView:setScrollHeight((#newMenu + (#self.items or 0))*MenuLableHeight)
			if #list == id and #self.items == 0 and #list*MenuLableHeight == scrollView.height then
				scrollView:scrollToPosition({
					y = -list[#list].y +((scrollView.height) - MenuLableHeight),
					time = 0
				})
			end
		end
		
		if value.items and #value.items ~= 0 then
			newLable.items = {}
			local itemsListGroup = display.newGroup()
			itemsListGroup.isVisible = false
			scrollView:insert(itemsListGroup)
			newLable.itemsGroup = itemsListGroup
			
			for k=1, #value.items do
				local valueSub = value.items[k]
				local keySub = valueSub.id
				
				local newSubLable = CreateNewLable(valueSub.name, newLable.x, newLable.y + ((k)*MenuLableHeight) , MenuLableWidth, MenuLableHeight)
				newSubLable.anchorY = 0
				newSubLable.anchorX = 0
				newSubLable.rect:setFillColor(23/255,45/255,58/255)
				itemsListGroup:insert(newSubLable)
				
				
				local itemGroup = display.newGroup()
				itemGroup.isVisible = false
				
				function newSubLable:tap(event)
					for d=1, #newLable.items do
						newLable.items[d].item.rect:setFillColor(23/255,45/255,58/255)
						newLable.items[d].group.isVisible = false
					end
					self.rect:setFillColor(9/255,112/255,230/255)
					itemGroup.isVisible = true
				end
				newSubLable:addEventListener("tap", newSubLable)
				
				newLable.items[k] = {item=newSubLable, name=keySub, group=itemGroup}
			end
		else
			local itemGroup = display.newGroup()
			itemGroup.isVisible = false
			newLable.itemsGroup = itemGroup
			newLable.items = {item=newLable, name=key, group=itemGroup}
		end
		newLable:addEventListener("tap", function() 
			newLable:OpenSub(r)
		end)
		scrollView:insert(newLable)
		list[r] = newLable
	end
	
	function scrollView:OpenSub(id, subID)
		if subID then  
			list[1]:OpenSub(id or 1, subID or 1)
		else
			list[id or 1]:OpenSub(id or 1)
		end
	end
	
	function scrollView:initialization(SceneGroup)
		for i=1, #list do
			if #list[i].items ~= 0 then
				for k=1, #list[i].items do
					local group = list[i].items[k].group
					SceneGroup:insert(group)
				end
			else
				local group = list[i].items.group
				SceneGroup:insert(group)
			end
		end
		SceneGroup:insert(self)
	end
	
	function scrollView:add(obj, idName)
		for i=1, #list do
			if #list[i].items ~= 0 then
				for k=1, #list[i].items do
					local group = list[i].items[k].group
					local name = list[i].items[k].name
					local item = list[i].items[k].item
					if name == idName then
						group:insert(obj)
					end
				end
			else
				local group = list[i].items.group
				local name = list[i].items.name
				local item = list[i].items.item
				if name == idName then
					group:insert(obj)
				end
			end
		end
	end
	
	--list[1]:OpenSub(1)
	scrollView:setScrollHeight((#newMenu)*MenuLableHeight)
	
	return scrollView
end

return lib